type KV<T> = Record<string, T>;
type State = KV<unknown>;
type DirectiveKV = KV<DirectiveData>;
interface DirectiveData {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    compute: (state: KV<unknown>, event?: Event) => any;
    value: string;
    deps: string[];
}
interface ASTNode {
    directives: DirectiveKV;
    deps: string[];
    el: HTMLElement;
    type: ASTNodeType;
}
declare enum ASTNodeType {
    NULL = -1,
    STATIC = 0,
    DYNAMIC = 1
}
/**
 * Holds state and AST, runs directives and renders content
 * Do not instantiate this directly, rather use the `component`
 * function to generate a Component.
 * @property {State} state - The data that pertains to the Component
 * @property {ASTNode[]} ast - The Abstract Syntax Tree that models the HTML
 */
declare class Component {
    state: State;
    ast: ASTNode[];
    constructor(state: State);
    /**
     * Initialize the component
     * @param {HTMLElement|string} el - Component element root
     * @returns {undefined}
     */
    mount(el: HTMLElement | string): void;
    /**
     * Force renders the DOM based on props
     * @param {string[]=} props - Array of root level properties in state
     * @returns {undefined}
     */
    render(props?: string[]): void;
}
/**
 * Instantiates and returns a Component class. NOTE: components may
 * only be mounted once on one element.
 * @param {State} state - The data that pertains to the Component
 * @returns {Component}
 */
declare const component: (state: State) => Component;
/**
 * Initialize components defined in HTML with `l-state`
 * @param {HTMLElement|Document} element - Root element to find uninitialized components
 */
declare const init: (element?: HTMLElement | Document) => void;
export { component, init };
